CustomerService class

Inheritance

Constructors

CustomerService(dynamic baseUrl, dynamic headers, dynamic options)

Properties

accessToken ↔ String?
getter/setter pairinherited
baseOptions ↔ Options?
getter/setter pairinherited
baseUrl ↔ String
getter/setter pair
baseUrlRoot ↔ String
getter/setter pairinherited
dio → Dio
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
headerDefault ↔ Map<String, String>
getter/setter pairinherited
headerParams ↔ HeadersInput
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

confirmCurrentEmailToChangeEmailPasswordless(TokenInput body) → Future<ResponseModel>
Change email step two confirm current email
confirmCurrentEmailToChangePhonePasswordless(TokenInput body) → Future<ResponseModel>
Change phone step two confirm current email
confirmCurrentPhoneToChangeEmailPasswordless(TokenOtpInput body) → Future<ResponseModel>
Change email step three confirm current phone
confirmCurrentPhoneToChangePhonePasswordless(TokenOtpInput body) → Future<ResponseModel>
Change phone step three confirm current phone
confirmEmailLoginPasswordless(TokenInput body) → Future<ResponseModel>
Confirm email Login Passwordless
confirmEmailRegistrationPasswordless(TokenInput body) → Future<ResponseModel>
Confirm email registration
confirmNewEmailToChangeEmailPasswordless(TokenInput body) → Future<ResponseModel>
Change email step five confirm new email
confirmNewPhoneToChangePhonePasswordless(TokenOtpInput body) → Future<ResponseModel>
Change phone step five confirm new phone
confirmPhoneLoginPasswordless(TokenOtpInput body) → Future<ResponseModel>
Confirm phone number login Passwordless
confirmPhoneRegistrationPasswordless(TokenOtpInput body) → Future<ResponseModel>
Confirm phone number registration
deleteProfile() → Future<ResponseModel>
Delete customer profile
deletex<T>(String path, {Options? queryParams, Object? body}) → Future<Response>
inherited
getById(String id) → Future<ResponseModel>
Get customer by Id
getx<T>(String path, {Options? queryParams}) → Future<Response>
inherited
handleRefreshToken() → Future<bool>
inherited
loginByEmailAndPassword(EmailPasswordInput body) → Future<ResponseModel>
Login by email and password
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patchx<T>(String path, {Options? queryParams, Object? body}) → Future<Response>
inherited
postx<T>(String path, {Options? queryParams, Object? body}) → Future<Response>
inherited
profile() → Future<ResponseModel>
Get customer profile
putx<T>(String path, {Options? queryParams, Object? body}) → Future<Response>
inherited
registrationEmail(RegistrationCustomerEmailPasswordInput body) → Future<ResponseModel>
Registration email
registrationEmailPasswordless(EmailInput body) → Future<ResponseModel>
registrationPhoneNumberPasswordless(TokenPhoneInput body) → Future<ResponseModel>
Registration phone number
registrationResendOtpPasswordless(TokenInput body) → Future<ResponseModel>
Registration resend otp
resendOtpLoginPasswordless(TokenInput body) → Future<ResponseModel>
Login resend otp Passwordless
resendOtpNewPhoneToChangePhonePasswordless(TokenInput body) → Future<ResponseModel>
Change phone step four resend otp
resendOtpToChangeEmailPasswordless(TokenInput body) → Future<ResponseModel>
Change email step two resend otp
resendOtpToChangePhonePasswordless(TokenInput body) → Future<ResponseModel>
Change phone step two resend otp
toString() → String
A string representation of this object.
inherited
updateProfile(ProfileInput body) → Future<ResponseModel>
Update customer profile
verifyCurrentEmailToChangeEmailPasswordless(EmailInput body) → Future<ResponseModel>
Change email step one verify current email
verifyCurrentEmailToChangePhonePasswordless(EmailInput body) → Future<ResponseModel>
Change phone step one verify current email
verifyEmailLoginPasswordless(EmailInput body) → Future<ResponseModel>
Verify email login Passwordless
verifyNewEmailToChangeEmailPasswordless(TokenNewEmailInput body) → Future<ResponseModel>
Change email step four verify new email
verifyNewPhoneToChangePhonePasswordless(TokenNewPhoneInput body) → Future<ResponseModel>
Change phone step four verify new phone

Operators

operator ==(Object other) → bool
The equality operator.
inherited